$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Product" },
            { data: "Factory Order Number" },
            { data: "Factory" },
            { data: "Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 5 },
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
            { width: 30, targets: 8 },
        ],
    });

    allPwrRecords();
});

function allPwrRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/ProductionWeightReportHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () { },
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no =
                        response.data.result[i]["reference_no"];
                    var product_name = response.data.result[i]["product_name"];
                    var manufacturing_order_no =
                        response.data.result[i]["manufacturing_order_no"];
                        var factory =
                        response.data.result[i]["factory"];
                    var date =
                        response.data.result[i]["date"];
                    var pwr_id = response.data.result[i]["pwr_id"];
                    data.push({
                        "Reference No": reference_no,
                        Product: product_name,
                        "Factory Order Number": manufacturing_order_no,
                        "Factory": factory,
                        "Date": date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            pwr_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            pwr_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            pwr_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            pwr_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () { },
    });
}

function edit(id) {
    location.href = "/qc/pwReport?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/pwReport?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/ProductionWeightReportHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allPwrRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

function print(id) {
    $.ajax({
        type: "GET",
        url:
            "/qc/ProductionWeightReportHeaderController/pwReportPrint/" +
            id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {},
        success: function (response) {
            console.log(response);
            var result = response.data.result;
            console.log(result);
            pwReportPrint(result, "PRINT");
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {},
    });
}

function pwReportPrint(result, flag) {
    var headerFontSize = 8;
    var Title = [{ text: "" }];

    var header_data = result.header;

    var Header = [
        {
            content: [
                {
                    table: {
                        widths: ["*"],
                        headerRows: 1,
                        body: [
                            [
                                {
                                    text: Page.getReportName(),
                                    fontSize: 16,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [
                                {
                                    text: "Production Weight Report",
                                    fontSize: 14,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [
                                {
                                    table: {
                                        widths: ["*", 150],
                                        headerRows: 1,
                                        body: [
                                            [
                                                {
                                                    text:
                                                        "Reference No : " +
                                                        header_data.reference_no,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Product : " +
                                                        header_data.product,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory Order Number : " +
                                                        header_data.factory_order_number,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory : " +
                                                        header_data.factory,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Date : " +
                                                        header_data.date,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                        ],
                                    },
                                    border: [false, false, false, false],
                                },
                            ],
                        ],
                    },
                    margin: [0, 0],
                },
            ],
        },
    ];

    var Body = [
        {
            table: {
                widths: [
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                    "*",
                ],
                headerRows: 1,
                body: getBodyData(result.body),
            },
        },
        {
            table: {
                widths: ["*"],
                headerRows: 1,
                body: [
                    [
                        {
                            text: "OB - Observation",
                            fontSize: 7,
                            margin: [0, 5, 0, 0],
                            color: "gray",
                            bold: false,
                            alignment: "left",
                            border: [false, false, false, false],
                        },
                    ],
                ],
            },
            border: [false, false, false, false],
        },
    ];

    var Footer = [
        {
            color: "red",
            fontSize: 8,
            alignment: "center",
            margin: [0, 0],
        },
    ];

    var page = new Page();
    page.setPageSize("A4");
    page.setPageOrientation("landscape");
    page.setPageMargin([10, 10, 10, 10]);
    page.setTitle(Title);
    page.setHeader(Header, Page.EVERY);
    page.setBody(Body);
    page.setFooter(Footer);
    if (flag == "EXPORT") {
        page.export();
    } else if (flag == "PRINT") {
        page.preview();
    }
}

function getBodyData(result) {
    var font_size = 8;
    var body = [];
    body.push([
        {
            text: "Hours",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "Sample No",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "OB 1",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "OB 2",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "OB 3",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "OB 4",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "OB 5",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
        {
            text: "Average",
            fontSize: font_size,
            bold: true,
            alignment: "center",
            border: [true, true, true, true],
        },
    ]);

    var data = result.data;
    for (i = 0; i < data.length; i++) {
        body.push([
            {
                text: data[i].hour,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].sample_no,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].ob1,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].ob2,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].ob3,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].ob4,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].ob5,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
            {
                text: data[i].average,
                fontSize: font_size,
                alignment: "center",
                border: [true, true, true, true],
            },
        ]);
    }

    return body;
}



/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}
