$(document).ready(function () {
    $("#myTable").DataTable({
        scrollX: true,
        order: [],
        columns: [
            { data: "Reference No" },
            { data: "Factory Order Number" },
            { data: "Product" },
            { data: "Factory" },
            { data: "Shift" },
            { data: "Date" },
            { data: "edit", className: "edit", orderable: false },
            { data: "view", className: "view", orderable: false },
            { data: "print", className: "print", orderable: false },
            { data: "delete", className: "delete", orderable: false },
        ],
        columnDefs: [
            { width: 30, targets: 6 },
            { width: 30, targets: 7 },
            { width: 30, targets: 8 },
            { width: 30, targets: 9 },
        ],
    });

    allSclRecords();
});

function allSclRecords() {
    $.ajax({
        type: "GET",
        url: "/qc/SupervisorCheckListHeaderController/records",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {},
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var reference_no = response.data.result[i]["reference_no"];
                    var product_name = response.data.result[i]["product_name"];
                    var manufacturing_order_no =
                        response.data.result[i]["manufacturing_order_no"];
                    var factory = response.data.result[i]["factory"];
                    var shift = response.data.result[i]["shift"];
                    var date = response.data.result[i]["date"];
                    var scl_id = response.data.result[i]["scl_id"];
                    data.push({
                        "Reference No": reference_no,
                        "Factory Order Number": manufacturing_order_no,
                        Product: product_name,
                        Factory: factory,
                        Shift: shift,
                        Date: date,
                        edit:
                            '<button class="btn btn-primary" onclick="edit(' +
                            scl_id +
                            ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        view:
                            '<button class="btn btn-success" onclick="view(' +
                            scl_id +
                            ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        print:
                            '<button class="btn btn-instagram" onclick="print(' +
                            scl_id +
                            ')"><i class="fa fa-print" aria-hidden="true"></i></button>',
                        delete:
                            '<button class="btn btn-danger" onclick="_delete(' +
                            scl_id +
                            ')"><i class="fa fa-trash" aria-hidden="true"></i></button>',
                    });
                }

                var table = $("#myTable").DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);
        },
        complete: function () {},
    });
}

function edit(id) {
    location.href = "/qc/supervisorChecking?id=" + id + "&action=edit";
}

function view(id) {
    location.href = "/qc/supervisorChecking?id=" + id + "&action=view";
}

function _delete(id) {
    showAlert("Are You Sure?", id);
}

function showAlert(message, id) {
    swal({
        title: message,
        text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: true,
        dangerMode: true,
    });

    $(".swal-button--confirm").on("click", function () {
        $.ajax({
            type: "DELETE",
            headers: {
                "X-CSRF-TOKEN": $('meta[name="csrf-token"]').attr("content"),
            },
            url: "/qc/SupervisorCheckListHeaderController/delete/" + id,
            success: function (response) {
                console.log(response);
                allSclRecords();
            },
            error: function (data) {
                console.log(data);
            },
        });
    });
}

function print(id) {
    $.ajax({
        type: "GET",
        url:
            "/qc/SupervisorCheckListHeaderController/supervisorCheckListReport/" +
            id,
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {},
        success: function (response) {
            console.log(response);
            var result = response.data.result;
            console.log(result);
            supervisorCheckingPrint(result, "PRINT");
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        },
    });
}

function supervisorCheckingPrint(result, flag) {
    var font_size = 8;
    var Title = [{ text: "" }];

    var header_data = result.header;

    var Header = [
        {
            content: [
                {
                    table: {
                        widths: ["*"],
                        headerRows: 1,
                        body: [
                            [
                                {
                                    text: Page.getReportName(),
                                    fontSize: 16,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [
                                {
                                    text: "Supervisor Check List",
                                    fontSize: 14,
                                    bold: true,
                                    alignment: "center",
                                    border: [false, false, false, false],
                                },
                            ],
                            [
                                {
                                    table: {
                                        widths: ["*", 150],
                                        headerRows: 1,
                                        body: [
                                            [
                                                {
                                                    text:
                                                        "Reference No : " +
                                                        header_data.reference_no,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Product : " +
                                                        header_data.product,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Factory Order Number : " +
                                                        header_data.factory_order_number,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                            [
                                                {
                                                    text: "",
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "left",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                                {
                                                    text:
                                                        "Date : " +
                                                        header_data.date,
                                                    fontSize: 9,
                                                    bold: false,
                                                    alignment: "right",
                                                    border: [
                                                        false,
                                                        false,
                                                        false,
                                                        false,
                                                    ],
                                                },
                                            ],
                                        ],
                                    },
                                    border: [false, false, false, false],
                                },
                            ],
                        ],
                    },
                    margin: [0, 0],
                },
            ],
        },
    ];

    var Body = [

        {
			table: {
				widths: [75, 75, '*'],
				body: getBodyData(result),
			}
		},
        {
            margin: [0, 15],
            table: {
                widths: ["*", 150],
                headerRows: 1,
                body: [
                    [
                        {
                            text:
                                "Supervisor Name :",
                            fontSize: 9,
                            bold: false,
                            alignment: "left",
                            border: [
                                false,
                                false,
                                false,
                                false,
                            ],
                        },
                        {
                            text:
                                "Signature :",
                            fontSize: 9,
                            bold: false,
                            alignment: "left",
                            border: [
                                false,
                                false,
                                false,
                                false,
                            ],
                        },
                    ],
                ],
            },
        }
    ];

    var Footer = [
        {
            color: "red",
            fontSize: 8,
            alignment: "center",
            margin: [0, 0],
        },
    ];

    var page = new Page();
    page.setPageSize("A4");
    page.setPageOrientation("landscape");
    page.setPageMargin([10, 10, 10, 10]);
    page.setTitle(Title);
    page.setHeader(Header, Page.EVERY);
    page.setBody(Body);
    page.setFooter(Footer);
    if (flag == "EXPORT") {
        page.export();
    } else if (flag == "PRINT") {
        page.preview();
    }
}

function getBodyData(result) {
    var body_data = result.body;
    var materialData = result.materialData;
    var machineData = result.machineData;
    var font_size = 8;
    var body = [];

    body.push(
        [
            {
                text: "Net Size",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2,
            },
            {

            },
            {
                text: body_data.net_size,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "Scales - Mixing Area",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2,
            },
            {

            },
            {
                text: body_data.scales_mixing_area,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "Scales - Finished Good Area",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2,
            },
            {

            },
            {
                text: body_data.scales_finished_good_area,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "Volume Bucket Accuracy",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2.
            },
            {

            },
            {
                text: body_data.volume_bucket_accuracy,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "No of QCs",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2.
            },
            {

            },
            {
                text: body_data.no_of_qcs,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "QC Allocated Places",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                colSpan: 2.
            },
            {

            },
            {
                text: body_data.qc_allocated_places,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            },
        ],
        [
            {
                text: "Material Type",
                fontSize: font_size,
                bold: true,
                alignment: "left",
                rowSpan: materialData.data.length,
            },
            {
                text: materialData.data[0].material_name,
                fontSize: font_size,
                bold: true,
                alignment: "left",
            },
            {
                text: materialData.data[0].remarks,
                fontSize: font_size,
                bold: false,
                alignment: "left",
            }
        ],
    );

    var data = materialData.data;
    for (i = 1; i < data.length; i++) {
        body.push([
            {

            },
            {
                text: materialData.data[i].material_name,
                fontSize: font_size,
                bold: true,
                alignment: "left",
            },
            {
                text: materialData.data[i].remarks,
                fontSize: font_size,
                alignment: "left",
            },
        ]);
    }

    body.push([
        {
            text: "Machine",
            fontSize: font_size,
            bold: true,
            alignment: "left",
            rowSpan: machineData.data.length,
        },
        {
            text: machineData.data[0].machinery_name,
            fontSize: font_size,
            bold: true,
            alignment: "left",
        },
        {
            text: machineData.data[0].remarks,
            fontSize: font_size,
            bold: false,
            alignment: "left",
        }
    ]);

    var mtData = machineData.data;
    for (i = 1; i < mtData.length; i++) {
        body.push([
            {

            },
            {
                text: machineData.data[i].machinery_name,
                fontSize: font_size,
                bold: true,
                alignment: "left",
            },
            {
                text: machineData.data[i].remarks,
                fontSize: font_size,
                alignment: "left",
            },
        ]);
    }

    return body;
}

/**
 * showSuccessMessage
 * This function is used to show success message.
 * @param message This is the paramter to require message content
 */
function showSuccessMessage(message) {
    toastr.success(message);
}

/**
 * showWarningMessage
 * This function is used to show warning message.
 * @param message This is the paramter to require message content
 */
function showWarningMessage(message) {
    toastr.warning(message);
}

/**
 * showErrorMessage
 * This function is used to show error message.
 * @param message This is the paramter to require message content
 */
function showErrorMessage() {
    toastr.error("Something went wrong");
}
